'''OpenGL extension ARB.occlusion_query2

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.occlusion_query2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension trivially adds a boolean occlusion query
	to ARB_occlusion_query.
	
	While the counter-based occlusion query provided by
	ARB_occlusion_query is flexible, there is still value
	to a simple boolean, which is often sufficient for applications.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/occlusion_query2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.occlusion_query2 import *
from OpenGL.raw.GL.ARB.occlusion_query2 import _EXTENSION_NAME

def glInitOcclusionQuery2ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION