'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_EXT_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_EXT_robustness',error_checker=_errors._error_checker)
GL_CONTEXT_ROBUST_ACCESS_EXT=_C('GL_CONTEXT_ROBUST_ACCESS_EXT',0x90F3)
GL_GUILTY_CONTEXT_RESET_EXT=_C('GL_GUILTY_CONTEXT_RESET_EXT',0x8253)
GL_INNOCENT_CONTEXT_RESET_EXT=_C('GL_INNOCENT_CONTEXT_RESET_EXT',0x8254)
GL_LOSE_CONTEXT_ON_RESET_EXT=_C('GL_LOSE_CONTEXT_ON_RESET_EXT',0x8252)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NO_RESET_NOTIFICATION_EXT=_C('GL_NO_RESET_NOTIFICATION_EXT',0x8261)
GL_RESET_NOTIFICATION_STRATEGY_EXT=_C('GL_RESET_NOTIFICATION_STRATEGY_EXT',0x8256)
GL_UNKNOWN_CONTEXT_RESET_EXT=_C('GL_UNKNOWN_CONTEXT_RESET_EXT',0x8255)
@_f
@_p.types(_cs.GLenum,)
def glGetGraphicsResetStatusEXT():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glGetnUniformfvEXT(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glGetnUniformivEXT(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glReadnPixelsEXT(x,y,width,height,format,type,bufSize,data):pass
