'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_float',error_checker=_errors._error_checker)
GL_ALPHA16F_ARB=_C('GL_ALPHA16F_ARB',0x881C)
GL_ALPHA32F_ARB=_C('GL_ALPHA32F_ARB',0x8816)
GL_INTENSITY16F_ARB=_C('GL_INTENSITY16F_ARB',0x881D)
GL_INTENSITY32F_ARB=_C('GL_INTENSITY32F_ARB',0x8817)
GL_LUMINANCE16F_ARB=_C('GL_LUMINANCE16F_ARB',0x881E)
GL_LUMINANCE32F_ARB=_C('GL_LUMINANCE32F_ARB',0x8818)
GL_LUMINANCE_ALPHA16F_ARB=_C('GL_LUMINANCE_ALPHA16F_ARB',0x881F)
GL_LUMINANCE_ALPHA32F_ARB=_C('GL_LUMINANCE_ALPHA32F_ARB',0x8819)
GL_RGB16F_ARB=_C('GL_RGB16F_ARB',0x881B)
GL_RGB32F_ARB=_C('GL_RGB32F_ARB',0x8815)
GL_RGBA16F_ARB=_C('GL_RGBA16F_ARB',0x881A)
GL_RGBA32F_ARB=_C('GL_RGBA32F_ARB',0x8814)
GL_TEXTURE_ALPHA_TYPE_ARB=_C('GL_TEXTURE_ALPHA_TYPE_ARB',0x8C13)
GL_TEXTURE_BLUE_TYPE_ARB=_C('GL_TEXTURE_BLUE_TYPE_ARB',0x8C12)
GL_TEXTURE_DEPTH_TYPE_ARB=_C('GL_TEXTURE_DEPTH_TYPE_ARB',0x8C16)
GL_TEXTURE_GREEN_TYPE_ARB=_C('GL_TEXTURE_GREEN_TYPE_ARB',0x8C11)
GL_TEXTURE_INTENSITY_TYPE_ARB=_C('GL_TEXTURE_INTENSITY_TYPE_ARB',0x8C15)
GL_TEXTURE_LUMINANCE_TYPE_ARB=_C('GL_TEXTURE_LUMINANCE_TYPE_ARB',0x8C14)
GL_TEXTURE_RED_TYPE_ARB=_C('GL_TEXTURE_RED_TYPE_ARB',0x8C10)
GL_UNSIGNED_NORMALIZED_ARB=_C('GL_UNSIGNED_NORMALIZED_ARB',0x8C17)

