"""Array-size annotations for OpenGL.raw.GLUT

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GLUT as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid

STRING = c_char_p



__all__ = [
    
]
