'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_cull_vertex'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_cull_vertex',error_checker=_errors._error_checker)
GL_CULL_VERTEX_EXT=_C('GL_CULL_VERTEX_EXT',0x81AA)
GL_CULL_VERTEX_EYE_POSITION_EXT=_C('GL_CULL_VERTEX_EYE_POSITION_EXT',0x81AB)
GL_CULL_VERTEX_OBJECT_POSITION_EXT=_C('GL_CULL_VERTEX_OBJECT_POSITION_EXT',0x81AC)
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glCullParameterdvEXT(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glCullParameterfvEXT(pname,params):pass
