'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_APPLE_clip_distance'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_APPLE_clip_distance',error_checker=_errors._error_checker)
GL_CLIP_DISTANCE0_APPLE=_C('GL_CLIP_DISTANCE0_APPLE',0x3000)
GL_CLIP_DISTANCE1_APPLE=_C('GL_CLIP_DISTANCE1_APPLE',0x3001)
GL_CLIP_DISTANCE2_APPLE=_C('GL_CLIP_DISTANCE2_APPLE',0x3002)
GL_CLIP_DISTANCE3_APPLE=_C('GL_CLIP_DISTANCE3_APPLE',0x3003)
GL_CLIP_DISTANCE4_APPLE=_C('GL_CLIP_DISTANCE4_APPLE',0x3004)
GL_CLIP_DISTANCE5_APPLE=_C('GL_CLIP_DISTANCE5_APPLE',0x3005)
GL_CLIP_DISTANCE6_APPLE=_C('GL_CLIP_DISTANCE6_APPLE',0x3006)
GL_CLIP_DISTANCE7_APPLE=_C('GL_CLIP_DISTANCE7_APPLE',0x3007)
GL_MAX_CLIP_DISTANCES_APPLE=_C('GL_MAX_CLIP_DISTANCES_APPLE',0x0D32)

